AGW Logo

svn SVN Revision 68881 For genericmessagedialog

This file contains the SVN revision history for genericmessagedialog, at revision 68881.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 20:51:43 UTC
  • Committer: AG
  • File Size: 45393 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

  • AGW: General overhaul of the documentation, much improved. All the widgets have their own sample usage in the docs as well;

  • FlatNotebook: Added the FNB_NAV_BUTTONS_WHEN_NEEDED style, which hides the navigation left/right arrows if all tabs fit;

  • RibbonBar: - Added the EVT_RIBBONBAR_TAB_LEFT_DCLICK event, which generates a special event

    when a ribbon bar tab is double-clicked;

    • Added support for toggle buttons;
    • Improved support for ribbon panel sizers: panels with sizers should now automatically minimise at small sizes, and behave properly when popping up from a minimised state;
    • Added tooltips via SetToolTip for those buttons which have the help_string attribute set.
  • XLSGrid: a new widget was added to AGW, termed XLSGrid. It’s based on wx.grid.Grid and can be used to faithfully reproduce the appearance of a Microsoft Excel spreadsheets.


svn_diff Diff To Previous Version (68362)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/genericmessagedialog.py       2011/07/24 21:36:47     68362
+++ wxPython/3rdParty/AGW/agw/genericmessagedialog.py       2011/08/25 16:40:17     68881
@@ -2,7 +2,7 @@
# GENERICMESSAGEDIALOG wxPython IMPLEMENTATION
#
# Andrea Gavana, @ 07 October 2008
# Latest Revision: 22 Jul 2011, 21.00 GMT
#
#
# TODO List
@@ -45,10 +45,33 @@
And a lot more. Check the demo for an almost complete review of the functionalities.


+Usage
+=====
+
+Usage example::
+
+    import wx
+    import wx.lib.agw.genericmessagedialog as GMD
+
+    # Our normal wxApp-derived class, as usual
+    app = wx.App(0)
+
+    main_message = "Hello world! I am the main message."
+
+    dlg = GMD.GenericMessageDialog(None, main_message, "A Nice Message Box",
+                                   agwStyle=wx.ICON_INFORMATION|wx.OK)
+
+    dlg.ShowModal()
+    dlg.Destroy()
+
+    app.MainLoop()
+
+
+
Supported Platforms
===================

-GenericMessageDialog has been tested on the following platforms:
+L{GenericMessageDialog} has been tested on the following platforms:
* Windows (Windows XP).


@@ -64,6 +87,24 @@
``GMD_USE_GRADIENTBUTTONS``        0x40 Uses `wx.lib.agw.gradientbutton` buttons instead of generic buttons.
=========================== =========== ==================================================

+The styles above are mutually exclusive. The style chosen above can be combined with a
+bitlist containing flags chosen from the following:
+
+=========================== =========== ==================================================
+Window Styles               Hex Value   Description
+=========================== =========== ==================================================
+``wx.OK``                           0x4 Shows an ``OK`` button.
+``wx.CANCEL``                      0x10 Shows a ``Cancel`` button.
+``wx.YES_NO``                       0xA Show ``Yes`` and ``No`` buttons.
+``wx.YES_DEFAULT``                  0x0 Used with ``wx.YES_NO``, makes ``Yes`` button the default - which is the default behaviour.
+``wx.NO_DEFAULT``                  0x80 Used with ``wx.YES_NO``, makes ``No`` button the default.
+``wx.ICON_EXCLAMATION``           0x100 Shows an exclamation mark icon.
+``wx.ICON_HAND``                  0x200 Shows an error icon.
+``wx.ICON_ERROR``                 0x200 Shows an error icon - the same as ``wx.ICON_HAND``.
+``wx.ICON_QUESTION``              0x400 Shows a question mark icon.
+``wx.ICON_INFORMATION``           0x800 Shows an information icon.
+=========================== =========== ==================================================
+

Events Processing
=================
@@ -74,9 +115,9 @@
License And Version
===================

-GenericMessageDialog is distributed under the wxPython license.
+L{GenericMessageDialog} is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 22 Jul 2011, 21.00 GMT
+Latest Revision: Andrea Gavana @ 17 Aug 2011, 15.00 GMT

Version 0.6

@@ -576,6 +617,24 @@
``GMD_USE_GRADIENTBUTTONS``        0x40 Uses L{GradientButton} buttons instead of generic buttons.
=========================== =========== ==================================================

+         The styles above are mutually exclusive. The style chosen above can be combined with a
+         bitlist containing flags chosen from the following:
+
+         =========================== =========== ==================================================
+         Window Styles               Hex Value   Description
+         =========================== =========== ==================================================
+         ``wx.OK``                           0x4 Shows an ``OK`` button.
+         ``wx.CANCEL``                      0x10 Shows a ``Cancel`` button.
+         ``wx.YES_NO``                       0xA Show ``Yes`` and ``No`` buttons.
+         ``wx.YES_DEFAULT``                  0x0 Used with ``wx.YES_NO``, makes ``Yes`` button the default - which is the default behaviour.
+         ``wx.NO_DEFAULT``                  0x80 Used with ``wx.YES_NO``, makes ``No`` button the default.
+         ``wx.ICON_EXCLAMATION``           0x100 Shows an exclamation mark icon.
+         ``wx.ICON_HAND``                  0x200 Shows an error icon.
+         ``wx.ICON_ERROR``                 0x200 Shows an error icon - the same as ``wx.ICON_HAND``.
+         ``wx.ICON_QUESTION``              0x400 Shows a question mark icon.
+         ``wx.ICON_INFORMATION``           0x800 Shows an information icon.
+         =========================== =========== ==================================================
+
:param `pos`: the dialog position on screen;
:param `size`: the dialog size;
:param `style`: the underlying `wx.Dialog` style;
@@ -2,7 +2,7 @@
#
# Andrea Gavana, @ 07 October 2008
-# Latest Revision: 22 Jul 2011, 21.00 GMT
+# Latest Revision: 17 Aug 2011, 15.00 GMT
#
#
Tree